searchNodes=[{"type":"module","title":"Validixir","doc":"Module containing all basic functionality needed for validation.","ref":"Validixir.html"},{"type":"function","title":"Validixir.and_then/2","doc":"Takes a validation result and a function. In case of a success the function is applied to the candidate and the result is returned. In case of a failure that failure is returned unchanged. This function is used to chain validations. Examples iex&gt; Validixir.Success . make ( 0 ) |&gt; Validixir . and_then ( fn x -&gt; Validixir.Success . make ( x + 1 ) end ) { :ok , 1 } iex&gt; Validixir.Failure . make ( [ ] ) |&gt; Validixir . and_then ( fn x -&gt; x + 1 end ) { :error , % Validixir.Failure { errors : [ ] , __message_lookup : %{ } } }","ref":"Validixir.html#and_then/2"},{"type":"function","title":"Validixir.augment_contexts/2","doc":"Augments a failure's error contexts if a failure is passed, else returns the success. Examples iex&gt; Validixir . pure ( 12 ) |&gt; Validixir . augment_contexts ( Hello ) { :ok , 12 } iex&gt; error_1 = Validixir.Error . make ( 1 , :message , Context ) iex&gt; error_2 = Validixir.Error . make ( 2 , :message , AnotherContext ) iex&gt; failure = Validixir.Failure . make ( [ error_1 , error_2 ] ) iex&gt; Validixir . augment_contexts ( failure , AdditionalContext ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : 1 , message : :message , context : [ AdditionalContext , Context ] } , % Validixir.Error { candidate : 2 , message : :message , context : [ AdditionalContext , AnotherContext ] } , ] , __message_lookup : %{ message : true } } }","ref":"Validixir.html#augment_contexts/2"},{"type":"function","title":"Validixir.augment_messages/2","doc":"Augments a failure's error messages if a failure is passed, else returns the success. Examples iex&gt; Validixir . pure ( 12 ) |&gt; Validixir . augment_messages ( Hello ) { :ok , 12 } iex&gt; error_1 = Validixir.Error . make ( 1 , :message , Context ) iex&gt; error_2 = Validixir.Error . make ( 2 , :another_message , Context ) iex&gt; failure = Validixir.Failure . make ( [ error_1 , error_2 ] ) iex&gt; Validixir . augment_messages ( failure , :additional_message ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : 1 , message : [ :additional_message , :message ] , context : Context } , % Validixir.Error { candidate : 2 , message : [ :additional_message , :another_message ] , context : Context } ] , __message_lookup : %{ [ :additional_message , :message ] =&gt; true , [ :additional_message , :another_message ] =&gt; true , :additional_message =&gt; true , :message =&gt; true , :another_message =&gt; true } } }","ref":"Validixir.html#augment_messages/2"},{"type":"function","title":"Validixir.failure_from_error/3","doc":"See Validixir.Failure.make_from_error/3 .","ref":"Validixir.html#failure_from_error/3"},{"type":"function","title":"Validixir.map/3","doc":"Takes a validation result and two functions that are applied as in map_success/2 and map_failure/2 respectively. Examples iex&gt; success = Validixir.Success . make ( 0 ) iex&gt; Validixir . map ( success , fn a -&gt; a + 1 end , fn _ -&gt; :does_nothing end ) { :ok , 1 } iex&gt; failure = Validixir.Failure . make ( [ Validixir.Error . make ( 1 , :hello , :hello ) ] ) iex&gt; Validixir . map ( failure , fn _ -&gt; :does_nothing end , fn err -&gt; % Validixir.Error { err | candidate : 2 } end ) { :error , % Validixir.Failure { errors : [ Validixir.Error . make ( 2 , :hello , :hello ) ] , __message_lookup : %{ hello : true } } }","ref":"Validixir.html#map/3"},{"type":"function","title":"Validixir.map_failure/2","doc":"Applies a function to each of the errors of a failure. If a success is passed it is returned unchanged. Examples iex&gt; success = Validixir.Success . make ( 0 ) iex&gt; Validixir . map_failure ( success , fn a -&gt; a + 1 end ) { :ok , 0 } iex&gt; failure = Validixir.Failure . make ( [ Validixir.Error . make ( 1 , :hello , :hello ) ] ) iex&gt; Validixir . map_failure ( failure , fn err -&gt; % Validixir.Error { err | candidate : 2 } end ) { :error , % Validixir.Failure { errors : [ Validixir.Error . make ( 2 , :hello , :hello ) ] , __message_lookup : %{ hello : true } } }","ref":"Validixir.html#map_failure/2"},{"type":"function","title":"Validixir.map_success/2","doc":"Applies a function to the candidate of a success. If a failure is passed it is returned unchanged. Examples iex&gt; success = Validixir.Success . make ( 0 ) iex&gt; Validixir . map_success ( success , fn a -&gt; a + 1 end ) { :ok , 1 } iex&gt; failure = Validixir.Failure . make ( [ ] ) iex&gt; Validixir . map_success ( failure , fn a -&gt; a + 1 end ) { :error , % Validixir.Failure { errors : [ ] , __message_lookup : %{ } } }","ref":"Validixir.html#map_success/2"},{"type":"function","title":"Validixir.override_contexts/2","doc":"Overrides a failure's error contexts if a failure is passed, else returns the success. Examples iex&gt; Validixir . pure ( 12 ) |&gt; Validixir . override_contexts ( Hello ) { :ok , 12 } iex&gt; error_1 = Validixir.Error . make ( 1 , :message , Context ) iex&gt; error_2 = Validixir.Error . make ( 2 , :another_message , Context ) iex&gt; failure = Validixir.Failure . make ( [ error_1 , error_2 ] ) iex&gt; Validixir . override_contexts ( failure , NewContext ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : 1 , message : :message , context : NewContext } , % Validixir.Error { candidate : 2 , message : :another_message , context : NewContext } ] , __message_lookup : %{ another_message : true , message : true } } }","ref":"Validixir.html#override_contexts/2"},{"type":"function","title":"Validixir.override_messages/2","doc":"Overrides a failure's error messages if a failure is passed, else returns the success. Examples iex&gt; Validixir . pure ( 12 ) |&gt; Validixir . override_messages ( Hello ) { :ok , 12 } iex&gt; error_1 = Validixir.Error . make ( 1 , :message , Context ) iex&gt; error_2 = Validixir.Error . make ( 2 , :another_message , Context ) iex&gt; failure = Validixir.Failure . make ( [ error_1 , error_2 ] ) iex&gt; Validixir . override_messages ( failure , :additional_message ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : 1 , message : :additional_message , context : Context } , % Validixir.Error { candidate : 2 , message : :additional_message , context : Context } ] , __message_lookup : %{ additional_message : true } } }","ref":"Validixir.html#override_messages/2"},{"type":"function","title":"Validixir.pure/1","doc":"Takes a value and lifts it in a validation result, returning a success with the value as its candidate. Examples iex&gt; Validixir . pure ( 12 ) { :ok , 12 }","ref":"Validixir.html#pure/1"},{"type":"function","title":"Validixir.seq/2","doc":"Applies a function wrapped in a validation success to the candidate of another validation success. If both validation results are failures it returns them combined. If only one is a failure, this failure is returned unchanged. This function is key in implementing applicatives. Examples iex&gt; s1 = Validixir.Success . make ( fn a -&gt; a + 1 end ) iex&gt; s2 = Validixir.Success . make ( 0 ) iex&gt; Validixir . seq ( s1 , s2 ) { :ok , 1 } iex&gt; error = Validixir.Error . make ( :hello , &quot;not allowed&quot; , nil ) iex&gt; failure = Validixir.Failure . make ( [ error ] ) iex&gt; success = Validixir.Success . make ( 1 ) iex&gt; Validixir . seq ( failure , success ) { :error , % Validixir.Failure { errors : [ error ] , __message_lookup : %{ &quot;not allowed&quot; =&gt; true } } } iex&gt; error1 = Validixir.Error . make ( :hello , &quot;not allowed&quot; , nil ) iex&gt; error2 = Validixir.Error . make ( :world , &quot;not allowed&quot; , nil ) iex&gt; failure1 = Validixir.Failure . make ( [ error1 ] ) iex&gt; failure2 = Validixir.Failure . make ( [ error2 ] ) iex&gt; Validixir . seq ( failure1 , failure2 ) { :error , % Validixir.Failure { errors : [ error1 , error2 ] , __message_lookup : %{ &quot;not allowed&quot; =&gt; true } } }","ref":"Validixir.html#seq/2"},{"type":"function","title":"Validixir.sequence/1","doc":"Takes a list of validation results and returns a success that contains the list of all candidates, if all validation results are successes. Else all failures are combined and a validation failure is returned. Examples iex&gt; Validixir . sequence ( [ Validixir.Success . make ( 1 ) , Validixir.Success . make ( 2 ) ] ) { :ok , [ 1 , 2 ] } iex&gt; error1 = Validixir.Error . make ( :hello , &quot;not allowed&quot; , nil ) iex&gt; error2 = Validixir.Error . make ( :world , &quot;not allowed&quot; , nil ) iex&gt; failure1 = Validixir.Failure . make ( [ error1 ] ) iex&gt; failure2 = Validixir.Failure . make ( [ error2 ] ) iex&gt; Validixir . sequence ( [ failure1 , failure2 ] ) { :error , % Validixir.Failure { errors : [ error1 , error2 ] , __message_lookup : %{ &quot;not allowed&quot; =&gt; true } } }","ref":"Validixir.html#sequence/1"},{"type":"function","title":"Validixir.sequence_of/2","doc":"Does the same as Validixir.sequence/1 but applies a validation function to all candidates first. Examples iex&gt; success_fn = fn c -&gt; Validixir.Success . make ( c ) end iex&gt; Validixir . sequence_of ( [ 1 , 2 ] , success_fn ) { :ok , [ 1 , 2 ] } iex&gt; failure_fn = fn c -&gt; [ Validixir.Error . make ( c , &quot;not allowed&quot; , nil ) ] |&gt; Validixir.Failure . make ( ) end iex&gt; Validixir . sequence_of ( [ :hello , :world ] , failure_fn ) { :error , % Validixir.Failure { errors : [ Validixir.Error . make ( :hello , [ { :index , 0 } , &quot;not allowed&quot; ] , nil ) , Validixir.Error . make ( :world , [ { :index , 1 } , &quot;not allowed&quot; ] , nil ) ] , __message_lookup : %{ &quot;not allowed&quot; =&gt; true , [ { :index , 0 } , &quot;not allowed&quot; ] =&gt; true , [ { :index , 1 } , &quot;not allowed&quot; ] =&gt; true , { :index , 0 } =&gt; true , { :index , 1 } =&gt; true } } }","ref":"Validixir.html#sequence_of/2"},{"type":"function","title":"Validixir.success/1","doc":"Same as pure/1 . Examples iex&gt; Validixir . success ( 12 ) { :ok , 12 }","ref":"Validixir.html#success/1"},{"type":"function","title":"Validixir.validate/2","doc":"Takes a function that is called if all validation results are successes. The call parameters are then the candidates in the respective order. The return value of this function call is then wrapped as a success and returned. If there is at least one failure, errors get accumulated and a validation failure is returned. Examples iex&gt; Validixir . validate ( fn a , b -&gt; { a , b } end , [ Validixir.Success . make ( 1 ) , Validixir.Success . make ( 2 ) ] ) { :ok , { 1 , 2 } } iex&gt; error1 = Validixir.Error . make ( :hello , &quot;not allowed&quot; , nil ) iex&gt; error2 = Validixir.Error . make ( :world , &quot;not allowed&quot; , nil ) iex&gt; failure1 = Validixir.Failure . make ( [ error1 ] ) iex&gt; failure2 = Validixir.Failure . make ( [ error2 ] ) iex&gt; Validixir . validate ( fn a , b -&gt; { a , b } end , [ failure1 , failure2 ] ) { :error , % Validixir.Failure { errors : [ error1 , error2 ] , __message_lookup : %{ &quot;not allowed&quot; =&gt; true } } }","ref":"Validixir.html#validate/2"},{"type":"function","title":"Validixir.validate_all/2","doc":"Applies a list of validation functions to a candidate. Returns a success that contains the candidate iff each validation function returns a success. Else returns a validation failure containing errors of each failed validation. Examples iex&gt; success_fn_1 = fn c -&gt; Validixir.Success . make ( c ) end iex&gt; success_fn_2 = fn _ -&gt; Validixir.Success . make ( 12 ) end iex&gt; Validixir . validate_all ( [ success_fn_1 , success_fn_2 ] , 1 ) { :ok , 1 } iex&gt; failure_fn = fn c -&gt; [ Validixir.Error . make ( c , &quot;not allowed&quot; , nil ) ] |&gt; Validixir.Failure . make ( ) end iex&gt; success_fn = fn _ -&gt; Validixir.Success . make ( 12 ) end iex&gt; Validixir . validate_all ( [ failure_fn , success_fn ] , :hello ) { :error , % Validixir.Failure { errors : [ Validixir.Error . make ( :hello , [ { :index , 0 } , &quot;not allowed&quot; ] , nil ) ] , __message_lookup : %{ &quot;not allowed&quot; =&gt; true , [ { :index , 0 } , &quot;not allowed&quot; ] =&gt; true , { :index , 0 } =&gt; true } } }","ref":"Validixir.html#validate_all/2"},{"type":"function","title":"Validixir.validation_result?/1","doc":"Returns true if a value is either a Validixir.Success or a Validixir.Failure , returns false else. Examples iex&gt; Validixir . validation_result? ( Validixir.Success . make ( 12 ) ) true iex&gt; Validixir . validation_result? ( Validixir.Failure . make ( [ ] ) ) true iex&gt; Validixir . validation_result? ( %{ } ) false iex&gt; { :error , internal_failure } = Validixir.Failure . make ( [ ] ) iex&gt; Validixir . validation_result? ( internal_failure )","ref":"Validixir.html#validation_result?/1"},{"type":"type","title":"Validixir.validate_all_return_t/1","doc":"","ref":"Validixir.html#t:validate_all_return_t/1"},{"type":"type","title":"Validixir.validation_fun_t/1","doc":"","ref":"Validixir.html#t:validation_fun_t/1"},{"type":"type","title":"Validixir.validation_result_t/1","doc":"A validation result is one of the following: A failure A success The type represents the possible results of a validation. The type takes a parameter that sets the candidate type in case of a success.","ref":"Validixir.html#t:validation_result_t/1"},{"type":"module","title":"Validixir.Error","doc":"Module containing data definition and functionality concerning an Error. An Error is a struct representing a concrete error in validation. An Error consists of the following: A candidate, representing the value that was validated A message, describing the cause of the Error A context in which the Error occured, e.g. a module or step","ref":"Validixir.Error.html"},{"type":"function","title":"Validixir.Error.augment_context/2","doc":"Augments the context of an error. Examples iex&gt; Validixir.Error . augment_context ( Validixir.Error . make ( 12 , :message , Context ) , NewContext ) % Validixir.Error { candidate : 12 , message : :message , context : [ NewContext , Context ] }","ref":"Validixir.Error.html#augment_context/2"},{"type":"function","title":"Validixir.Error.augment_message/2","doc":"Augments the message of an error. Examples iex&gt; Validixir.Error . augment_message ( Validixir.Error . make ( 12 , :message , Context ) , :new_message ) % Validixir.Error { candidate : 12 , message : [ :new_message , :message ] , context : Context }","ref":"Validixir.Error.html#augment_message/2"},{"type":"function","title":"Validixir.Error.make/3","doc":"Smart constructor of an error.","ref":"Validixir.Error.html#make/3"},{"type":"function","title":"Validixir.Error.with_context/2","doc":"Overrides the context of an error. Examples iex&gt; Validixir.Error . with_context ( Validixir.Error . make ( 12 , :message , Context ) , NewContext ) % Validixir.Error { candidate : 12 , message : :message , context : NewContext }","ref":"Validixir.Error.html#with_context/2"},{"type":"function","title":"Validixir.Error.with_message/2","doc":"Overrides the message of an error. Examples iex&gt; Validixir.Error . with_message ( Validixir.Error . make ( 12 , :message , Context ) , :new_message ) % Validixir.Error { candidate : 12 , message : :new_message , context : Context }","ref":"Validixir.Error.html#with_message/2"},{"type":"type","title":"Validixir.Error.t/0","doc":"","ref":"Validixir.Error.html#t:t/0"},{"type":"module","title":"Validixir.Failure","doc":"Module containing data definition and functionality concerning a Failure. A Failure is a error tuple that contains a Failure struct representing a failed validation. A Failure struct consists of the following: A list of Errors, displaying multiple causes for the validation to fail. A message lookup that is a map with all messages as keys. This lookup is used internally and should not be used directly. Optional meta information that is defined by the user.","ref":"Validixir.Failure.html"},{"type":"function","title":"Validixir.Failure.combine/2","doc":"Combines two errors. That is, appending their error lists. Examples iex&gt; error_1 = Validixir.Error . make ( 1 , :not_allowed , SomeContext ) iex&gt; error_2 = Validixir.Error . make ( 2 , :also_not_allowed , SomeContext ) iex&gt; failure_1 = Validixir.Failure . make ( [ error_1 ] ) iex&gt; failure_2 = Validixir.Failure . make ( [ error_2 ] ) iex&gt; Validixir.Failure . combine ( failure_1 , failure_2 ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : 1 , message : :not_allowed , context : SomeContext } , % Validixir.Error { candidate : 2 , message : :also_not_allowed , context : SomeContext } ] , __message_lookup : %{ not_allowed : true , also_not_allowed : true } } }","ref":"Validixir.Failure.html#combine/2"},{"type":"function","title":"Validixir.Failure.failure?/1","doc":"Returns true if a value is a failure. Examples iex&gt; f = Validixir.Failure . make ( [ ] ) iex&gt; Validixir.Failure . failure? ( f ) true iex&gt; s = Validixir.Success . make ( 1 ) iex&gt; Validixir.Failure . failure? ( s ) false","ref":"Validixir.Failure.html#failure?/1"},{"type":"function","title":"Validixir.Failure.make/2","doc":"Smart constructor of a failure.","ref":"Validixir.Failure.html#make/2"},{"type":"function","title":"Validixir.Failure.make_from_error/3","doc":"Constructs a failure with one error based on error parameters. Examples iex&gt; Validixir.Failure . make_from_error ( 12 , :twelve_not_allowed , SomeContext ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : 12 , message : :twelve_not_allowed , context : SomeContext } ] , __message_lookup : %{ twelve_not_allowed : true } } }","ref":"Validixir.Failure.html#make_from_error/3"},{"type":"function","title":"Validixir.Failure.map/2","doc":"Applies a function to each error in a failure's errors. Examples iex&gt; f = Validixir.Failure . make_from_error ( 1 , :message , :context ) iex&gt; Validixir.Failure . map ( f , fn % Validixir.Error { candidate : c } -&gt; Validixir.Error . make ( c + 1 , :message_new , :context ) end ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : 2 , message : :message_new , context : :context } ] , __message_lookup : %{ message_new : true } } }","ref":"Validixir.Failure.html#map/2"},{"type":"function","title":"Validixir.Failure.override_error_contexts/2","doc":"Overrides the context of all errors of a failure. Examples iex&gt; error_1 = Validixir.Error . make ( 1 , :not_allowed , SomeContext ) iex&gt; error_2 = Validixir.Error . make ( 2 , :not_allowed , SomeOtherContext ) iex&gt; f = Validixir.Failure . make ( [ error_1 , error_2 ] ) iex&gt; Validixir.Failure . override_error_contexts ( f , NewFailureContext ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : 1 , message : :not_allowed , context : NewFailureContext } , % Validixir.Error { candidate : 2 , message : :not_allowed , context : NewFailureContext } ] , __message_lookup : %{ not_allowed : true } } }","ref":"Validixir.Failure.html#override_error_contexts/2"},{"type":"function","title":"Validixir.Failure.override_error_messages/2","doc":"Overrides the message of all errors of a failure. Examples iex&gt; error_1 = Validixir.Error . make ( 1 , :not_allowed , SomeContext ) iex&gt; error_2 = Validixir.Error . make ( 2 , :also_not_allowed , SomeContext ) iex&gt; f = Validixir.Failure . make ( [ error_1 , error_2 ] ) iex&gt; Validixir.Failure . override_error_messages ( f , :nonono ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : 1 , message : :nonono , context : SomeContext } , % Validixir.Error { candidate : 2 , message : :nonono , context : SomeContext } ] , __message_lookup : %{ nonono : true } } }","ref":"Validixir.Failure.html#override_error_messages/2"},{"type":"function","title":"Validixir.Failure.put_meta/2","doc":"Puts meta into the failure.","ref":"Validixir.Failure.html#put_meta/2"},{"type":"type","title":"Validixir.Failure.failure_t/0","doc":"","ref":"Validixir.Failure.html#t:failure_t/0"},{"type":"type","title":"Validixir.Failure.t/0","doc":"","ref":"Validixir.Failure.html#t:t/0"},{"type":"module","title":"Validixir.Matchers","doc":"This module contains helper macros to use in matching. These macros can be used in with and case-statements as well as function headers. Example: case validation_result do success ( 21 ) -&gt; ... # matches a success with candidate 21 success ( ) -&gt; ... # matches a success { :error , failure ( :my_error ) } -&gt; ... # matches a failure that has the message # :my_error somewhere in errors { :error , failure ( ) } -&gt; ... # matches a failure end","ref":"Validixir.Matchers.html"},{"type":"macro","title":"Validixir.Matchers.failure/0","doc":"","ref":"Validixir.Matchers.html#failure/0"},{"type":"macro","title":"Validixir.Matchers.failure/1","doc":"","ref":"Validixir.Matchers.html#failure/1"},{"type":"macro","title":"Validixir.Matchers.success/0","doc":"","ref":"Validixir.Matchers.html#success/0"},{"type":"macro","title":"Validixir.Matchers.success/1","doc":"","ref":"Validixir.Matchers.html#success/1"},{"type":"module","title":"Validixir.Success","doc":"Module containing data definition and functionality concerning a Success. A Success is a :ok tuple representing a successful validation of a candidate.","ref":"Validixir.Success.html"},{"type":"function","title":"Validixir.Success.make/1","doc":"Smart constructor of a success.","ref":"Validixir.Success.html#make/1"},{"type":"function","title":"Validixir.Success.map/2","doc":"Applies a function to the candidate of a success. Examples iex&gt; Validixir.Success . map ( Validixir.Success . make ( 0 ) , fn a -&gt; a + 1 end ) { :ok , 1 }","ref":"Validixir.Success.html#map/2"},{"type":"function","title":"Validixir.Success.success?/1","doc":"Returns true if a value is a success. Examples iex&gt; f = Validixir.Failure . make ( [ ] ) iex&gt; Validixir.Success . success? ( f ) false iex&gt; s = Validixir.Success . make ( 1 ) iex&gt; Validixir.Success . success? ( s ) true","ref":"Validixir.Success.html#success?/1"},{"type":"type","title":"Validixir.Success.some_inner_t/0","doc":"","ref":"Validixir.Success.html#t:some_inner_t/0"},{"type":"type","title":"Validixir.Success.t/1","doc":"","ref":"Validixir.Success.html#t:t/1"},{"type":"module","title":"Validixir.Validations","doc":"This module contains premade validations for basic elixir types and often used functionality.","ref":"Validixir.Validations.html"},{"type":"function","title":"Validixir.Validations.atom/1","doc":"Returns a validation success if the candidate is an atom, returns a failure otherwise. Examples iex&gt; Validixir.Validations . atom ( :hello ) { :ok , :hello } iex&gt; Validixir.Validations . atom ( 12 ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : 12 , message : :not_an_atom , context : Validixir.Validations } ] , __message_lookup : %{ not_an_atom : true } } }","ref":"Validixir.Validations.html#atom/1"},{"type":"function","title":"Validixir.Validations.binary/1","doc":"Returns a validation success if the candidate is a binary, returns a failure otherwise. Examples iex&gt; Validixir.Validations . binary ( &quot;foo&quot; ) { :ok , &quot;foo&quot; } iex&gt; Validixir.Validations . binary ( &lt;&lt; 1 :: 3 &gt;&gt; ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : &lt;&lt; 1 :: 3 &gt;&gt; , message : :not_a_binary , context : Validixir.Validations } ] , __message_lookup : %{ not_a_binary : true } } }","ref":"Validixir.Validations.html#binary/1"},{"type":"function","title":"Validixir.Validations.bitstring/1","doc":"Returns a validation success if the candidate is a bitstring, returns a failure otherwise. Examples iex&gt; Validixir.Validations . bitstring ( &quot;foo&quot; ) { :ok , &quot;foo&quot; } iex&gt; Validixir.Validations . bitstring ( &lt;&lt; 1 :: 3 &gt;&gt; ) { :ok , &lt;&lt; 1 :: 3 &gt;&gt; } iex&gt; Validixir.Validations . bitstring ( 12 ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : 12 , message : :not_a_bitstring , context : Validixir.Validations } ] , __message_lookup : %{ not_a_bitstring : true } } }","ref":"Validixir.Validations.html#bitstring/1"},{"type":"function","title":"Validixir.Validations.boolean/1","doc":"Returns a validation success if the candidate is a boolean, returns a failure otherwise. Examples iex&gt; Validixir.Validations . boolean ( true ) { :ok , true } iex&gt; Validixir.Validations . boolean ( nil ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : nil , message : :not_a_boolean , context : Validixir.Validations } ] , __message_lookup : %{ not_a_boolean : true } } }","ref":"Validixir.Validations.html#boolean/1"},{"type":"function","title":"Validixir.Validations.empty_list/1","doc":"Returns a validation success if the candidate is an empty list, returns a failure otherwise. Examples iex&gt; Validixir.Validations . empty_list ( [ ] ) { :ok , [ ] } iex&gt; Validixir.Validations . empty_list ( [ 1 , 2 , 3 ] ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : [ 1 , 2 , 3 ] , message : :not_an_empty_list , context : Validixir.Validations } ] , __message_lookup : %{ not_an_empty_list : true } } } iex&gt; Validixir.Validations . empty_list ( %{ } ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : %{ } , message : :not_an_empty_list , context : Validixir.Validations } ] , __message_lookup : %{ not_an_empty_list : true } } }","ref":"Validixir.Validations.html#empty_list/1"},{"type":"function","title":"Validixir.Validations.exception/1","doc":"Returns a validation success if the candidate is an exception, returns a failure otherwise. Examples iex&gt; Validixir.Validations . exception ( % RuntimeError { } ) { :ok , % RuntimeError { } } iex&gt; Validixir.Validations . exception ( %{ } ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : %{ } , message : :not_an_exception , context : Validixir.Validations } ] , __message_lookup : %{ not_an_exception : true } } }","ref":"Validixir.Validations.html#exception/1"},{"type":"function","title":"Validixir.Validations.float/1","doc":"Returns a validation success if the candidate is a float, returns a failure otherwise. Examples iex&gt; Validixir.Validations . float ( 12.2 ) { :ok , 12.2 } iex&gt; Validixir.Validations . float ( 12 ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : 12 , message : :not_a_float , context : Validixir.Validations } ] , __message_lookup : %{ not_a_float : true } } }","ref":"Validixir.Validations.html#float/1"},{"type":"function","title":"Validixir.Validations.function/1","doc":"Returns a validation success if the candidate is a function, returns a failure otherwise. Examples iex&gt; Validixir.Validations . function ( &amp; Validixir . pure / 1 ) { :ok , &amp; Validixir . pure / 1 } iex&gt; Validixir.Validations . function ( 12 ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : 12 , message : :not_a_function , context : Validixir.Validations } ] , __message_lookup : %{ not_a_function : true } } }","ref":"Validixir.Validations.html#function/1"},{"type":"function","title":"Validixir.Validations.integer/1","doc":"Returns a validation success if the candidate is an integer, returns a failure otherwise. Examples iex&gt; Validixir.Validations . integer ( 12 ) { :ok , 12 } iex&gt; Validixir.Validations . integer ( 12.2 ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : 12.2 , message : :not_an_integer , context : Validixir.Validations } ] , __message_lookup : %{ not_an_integer : true } } }","ref":"Validixir.Validations.html#integer/1"},{"type":"function","title":"Validixir.Validations.list/1","doc":"Returns a validation success if the candidate is a list, returns a failure otherwise. Examples iex&gt; Validixir.Validations . list ( [ 1 , 2 , 3 ] ) { :ok , [ 1 , 2 , 3 ] } iex&gt; Validixir.Validations . list ( [ ] ) { :ok , [ ] } iex&gt; Validixir.Validations . list ( %{ } ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : %{ } , message : :not_a_list , context : Validixir.Validations } ] , __message_lookup : %{ not_a_list : true } } }","ref":"Validixir.Validations.html#list/1"},{"type":"function","title":"Validixir.Validations.map/1","doc":"Returns a validation success if the candidate is a map, returns a failure otherwise. Examples iex&gt; Validixir.Validations . map ( %{ } ) { :ok , %{ } } iex&gt; person_struct = % Example.Person { name : &quot;s&quot; , username : &quot;h&quot; , email : &quot;s@h.b&quot; , address : &quot;s h b&quot; } iex&gt; Validixir.Validations . map ( person_struct ) { :ok , person_struct } iex&gt; Validixir.Validations . map ( [ ] ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : [ ] , message : :not_a_map , context : Validixir.Validations } ] , __message_lookup : %{ not_a_map : true } } }","ref":"Validixir.Validations.html#map/1"},{"type":"function","title":"Validixir.Validations.map_key/2","doc":"Returns a validation success if the given map contains the given key, returns a failure otherwise. Examples iex&gt; Validixir.Validations . map_key ( %{ hello : :world } , :hello ) { :ok , { %{ hello : :world } , :hello } } iex&gt; Validixir.Validations . map_key ( %{ } , :hello ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : { %{ } , :hello } , message : :not_a_key_of_map , context : Validixir.Validations } ] , __message_lookup : %{ not_a_key_of_map : true } } }","ref":"Validixir.Validations.html#map_key/2"},{"type":"function","title":"Validixir.Validations.member/2","doc":"Returns a validation success if the enum contains the elem, returns a failure otherwise. Examples iex&gt; Validixir.Validations . member ( [ 1 , 2 , 3 ] , 1 ) { :ok , { [ 1 , 2 , 3 ] , 1 } } iex&gt; Validixir.Validations . member ( [ ] , 1 ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : { [ ] , 1 } , message : :not_a_member , context : Validixir.Validations } ] , __message_lookup : %{ not_a_member : true } } } iex&gt; Validixir.Validations . member ( [ 1 , 2 , 3 ] , 12 ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : { [ 1 , 2 , 3 ] , 12 } , message : :not_a_member , context : Validixir.Validations } ] , __message_lookup : %{ not_a_member : true } } }","ref":"Validixir.Validations.html#member/2"},{"type":"function","title":"Validixir.Validations.neg_integer/1","doc":"Returns a validation success if the candidate is a negative integer, returns a failure otherwise. Examples iex&gt; Validixir.Validations . neg_integer ( - 12 ) { :ok , - 12 } iex&gt; Validixir.Validations . neg_integer ( 0 ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : 0 , message : :not_a_negative_integer , context : Validixir.Validations } ] , __message_lookup : %{ not_a_negative_integer : true } } } iex&gt; Validixir.Validations . neg_integer ( 2 ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : 2 , message : :not_a_negative_integer , context : Validixir.Validations } ] , __message_lookup : %{ not_a_negative_integer : true } } }","ref":"Validixir.Validations.html#neg_integer/1"},{"type":"function","title":"Validixir.Validations.nil?/1","doc":"Returns a validation success if the candidate is nil, returns a failure otherwise. Since all other names are special words in elixir, we chose nil? for the name of the function. Examples iex&gt; Validixir.Validations . nil? ( nil ) { :ok , nil } iex&gt; Validixir.Validations . nil? ( 12 ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : 12 , message : :not_nil , context : Validixir.Validations } ] , __message_lookup : %{ not_nil : true } } }","ref":"Validixir.Validations.html#nil?/1"},{"type":"function","title":"Validixir.Validations.non_empty_list/1","doc":"Returns a validation success if the candidate is a non-empty list, returns a failure otherwise. Examples iex&gt; Validixir.Validations . non_empty_list ( [ 1 , 2 , 3 ] ) { :ok , [ 1 , 2 , 3 ] } iex&gt; Validixir.Validations . non_empty_list ( [ ] ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : [ ] , message : :not_a_non_empty_list , context : Validixir.Validations } ] , __message_lookup : %{ not_a_non_empty_list : true } } } iex&gt; Validixir.Validations . non_empty_list ( %{ } ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : %{ } , message : :not_a_non_empty_list , context : Validixir.Validations } ] , __message_lookup : %{ not_a_non_empty_list : true } } }","ref":"Validixir.Validations.html#non_empty_list/1"},{"type":"function","title":"Validixir.Validations.not_a_member/2","doc":"Returns a validation success if the enum does not contain the elem, returns a failure otherwise. Examples iex&gt; Validixir.Validations . not_a_member ( [ 1 , 2 , 3 ] , 4 ) { :ok , { [ 1 , 2 , 3 ] , 4 } } iex&gt; Validixir.Validations . not_a_member ( [ ] , 1 ) { :ok , { [ ] , 1 } } iex&gt; Validixir.Validations . not_a_member ( [ 1 , 2 , 3 ] , 1 ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : { [ 1 , 2 , 3 ] , 1 } , message : :is_a_member , context : Validixir.Validations } ] , __message_lookup : %{ is_a_member : true } } }","ref":"Validixir.Validations.html#not_a_member/2"},{"type":"function","title":"Validixir.Validations.not_nil/1","doc":"Returns a validation success if the candidate is not nil, returns a failure otherwise. Examples iex&gt; Validixir.Validations . not_nil ( 12 ) { :ok , 12 } iex&gt; Validixir.Validations . not_nil ( nil ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : nil , message : :is_nil , context : Validixir.Validations } ] , __message_lookup : %{ is_nil : true } } }","ref":"Validixir.Validations.html#not_nil/1"},{"type":"function","title":"Validixir.Validations.number/1","doc":"Returns a validation success if the candidate is a number, returns a failure otherwise. Examples iex&gt; Validixir.Validations . number ( 12.2 ) { :ok , 12.2 } iex&gt; Validixir.Validations . number ( 12 ) { :ok , 12 } iex&gt; Validixir.Validations . number ( nil ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : nil , message : :not_a_number , context : Validixir.Validations } ] , __message_lookup : %{ not_a_number : true } } }","ref":"Validixir.Validations.html#number/1"},{"type":"function","title":"Validixir.Validations.pid/1","doc":"Returns a validation success if the candidate is a pid, returns a failure otherwise. Examples iex&gt; Validixir.Validations . pid ( self ( ) ) { :ok , self ( ) } iex&gt; Validixir.Validations . pid ( 12 ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : 12 , message : :not_a_pid , context : Validixir.Validations } ] , __message_lookup : %{ not_a_pid : true } } }","ref":"Validixir.Validations.html#pid/1"},{"type":"function","title":"Validixir.Validations.port/1","doc":"Returns a validation success if the candidate is a port, returns a failure otherwise.","ref":"Validixir.Validations.html#port/1"},{"type":"function","title":"Validixir.Validations.pos_integer/1","doc":"Returns a validation success if the candidate is a positive integer, returns a failure otherwise. Examples iex&gt; Validixir.Validations . pos_integer ( 12 ) { :ok , 12 } iex&gt; Validixir.Validations . pos_integer ( 0 ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : 0 , message : :not_a_positive_integer , context : Validixir.Validations } ] , __message_lookup : %{ not_a_positive_integer : true } } } iex&gt; Validixir.Validations . pos_integer ( - 2 ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : - 2 , message : :not_a_positive_integer , context : Validixir.Validations } ] , __message_lookup : %{ not_a_positive_integer : true } } }","ref":"Validixir.Validations.html#pos_integer/1"},{"type":"function","title":"Validixir.Validations.reference/1","doc":"Returns a validation success if the candidate is a reference, returns a failure otherwise. Examples iex&gt; ref = make_ref ( ) iex&gt; Validixir.Validations . reference ( ref ) { :ok , ref } iex&gt; Validixir.Validations . reference ( 12 ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : 12 , message : :not_a_reference , context : Validixir.Validations } ] , __message_lookup : %{ not_a_reference : true } } }","ref":"Validixir.Validations.html#reference/1"},{"type":"function","title":"Validixir.Validations.struct/1","doc":"Returns a validation success if the candidate is a struct, returns a failure otherwise. Examples iex&gt; person_struct = % Example.Person { name : &quot;s&quot; , username : &quot;h&quot; , email : &quot;s@h.b&quot; , address : &quot;s h b&quot; } iex&gt; Validixir.Validations . struct ( person_struct ) { :ok , person_struct } iex&gt; Validixir.Validations . struct ( %{ } ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : %{ } , message : :not_a_struct , context : Validixir.Validations } ] , __message_lookup : %{ not_a_struct : true } } }","ref":"Validixir.Validations.html#struct/1"},{"type":"function","title":"Validixir.Validations.succeed/1","doc":"Always returns a validation success. Examples iex&gt; Validixir.Validations . succeed ( 12 ) { :ok , 12 }","ref":"Validixir.Validations.html#succeed/1"},{"type":"function","title":"Validixir.Validations.tuple/1","doc":"Returns a validation success if the candidate is a tuple, returns a failure otherwise. Examples iex&gt; Validixir.Validations . tuple ( { 1 , 2 , 3 } ) { :ok , { 1 , 2 , 3 } } iex&gt; Validixir.Validations . tuple ( [ 1 , 2 , 3 ] ) { :error , % Validixir.Failure { errors : [ % Validixir.Error { candidate : [ 1 , 2 , 3 ] , message : :not_a_tuple , context : Validixir.Validations } ] , __message_lookup : %{ not_a_tuple : true } } }","ref":"Validixir.Validations.html#tuple/1"}]